@@ -233,8 +233,9 @@ log_create_filename (char *buf, char *servname, char *channame, char *netname)
 				*tmp = rfc_tolower (*tmp);
 				if (*tmp == '/')
 #else
-				/* win32 can't handle filenames with \|/ characters */
-				if (*tmp == '\\' || *tmp == '|' || *tmp == '/')
+				/* win32 can't handle filenames with \|/>< characters */
+				if (*tmp == '\\' || *tmp == '|' || *tmp == '/' ||
+					 *tmp == '>' || *tmp == '<')
 #endif
 					*tmp = '_';
 			}
@@ -399,7 +400,7 @@ log_write (session *sess, char *text)
 				g_free (stamp);
 			}
 		}
-		temp = strip_color (text);
+		temp = strip_color (text, -1, 1, 1);
 		write (sess->logfd, temp, strlen (temp));
 		free (temp);
 	}
@@ -554,486 +555,486 @@ char *pntevts[NUM_XP];
 
 #define pevt_generic_none_help NULL
 
-static char *pevt_genmsg_help[] = {
+static char * const pevt_genmsg_help[] = {
 	N_("Left message"),
 	N_("Right message"),
 };
 
-static char *pevt_join_help[] = {
+static char * const pevt_join_help[] = {
 	N_("The nick of the joining person"),
 	N_("The channel being joined"),
 	N_("The host of the person"),
 };
 
-static char *pevt_chanaction_help[] = {
+static char * const pevt_chanaction_help[] = {
 	N_("Nickname"),
 	N_("The action"),
 };
 
-static char *pevt_chanmsg_help[] = {
+static char * const pevt_chanmsg_help[] = {
 	N_("Nickname"),
 	N_("The text"),
 	N_("Mode char"),
 	N_("Identified text"),
 };
 
-static char *pevt_privmsg_help[] = {
+static char * const pevt_privmsg_help[] = {
 	N_("Nickname"),
 	N_("The message"),
 };
 
-static char *pevt_changenick_help[] = {
+static char * const pevt_changenick_help[] = {
 	N_("Old nickname"),
 	N_("New nickname"),
 };
 
-static char *pevt_newtopic_help[] = {
+static char * const pevt_newtopic_help[] = {
 	N_("Nick of person who changed the topic"),
 	N_("Topic"),
 	N_("Channel"),
 };
 
-static char *pevt_topic_help[] = {
+static char * const pevt_topic_help[] = {
 	N_("Channel"),
 	N_("Topic"),
 };
 
-static char *pevt_kick_help[] = {
+static char * const pevt_kick_help[] = {
 	N_("The nickname of the kicker"),
 	N_("The person being kicked"),
 	N_("The channel"),
 	N_("The reason"),
 };
 
-static char *pevt_part_help[] = {
+static char * const pevt_part_help[] = {
 	N_("The nick of the person leaving"),
 	N_("The host of the person"),
 	N_("The channel"),
 };
 
-static char *pevt_chandate_help[] = {
+static char * const pevt_chandate_help[] = {
 	N_("The channel"),
 	N_("The time"),
 };
 
-static char *pevt_topicdate_help[] = {
+static char * const pevt_topicdate_help[] = {
 	N_("The channel"),
 	N_("The creator"),
 	N_("The time"),
 };
 
-static char *pevt_quit_help[] = {
+static char * const pevt_quit_help[] = {
 	N_("Nick"),
 	N_("Reason"),
 	N_("Host"),
 };
 
-static char *pevt_pingrep_help[] = {
+static char * const pevt_pingrep_help[] = {
 	N_("Who it's from"),
 	N_("The time in x.x format (see below)"),
 };
 
-static char *pevt_notice_help[] = {
+static char * const pevt_notice_help[] = {
 	N_("Who it's from"),
 	N_("The message"),
 };
 
-static char *pevt_channotice_help[] = {
+static char * const pevt_channotice_help[] = {
 	N_("Who it's from"),
 	N_("The Channel it's going to"),
 	N_("The message"),
 };
 
-static char *pevt_dprivmsg_help[] = {
+static char * const pevt_dprivmsg_help[] = {
 	N_("Nickname"),
 	N_("The message"),
 	N_("Identified text"),
 };
 
-static char *pevt_uchangenick_help[] = {
+static char * const pevt_uchangenick_help[] = {
 	N_("Old nickname"),
 	N_("New nickname"),
 };
 
-static char *pevt_ukick_help[] = {
+static char * const pevt_ukick_help[] = {
 	N_("The person being kicked"),
 	N_("The channel"),
 	N_("The nickname of the kicker"),
 	N_("The reason"),
 };
 
-static char *pevt_partreason_help[] = {
+static char * const pevt_partreason_help[] = {
 	N_("The nick of the person leaving"),
 	N_("The host of the person"),
 	N_("The channel"),
 	N_("The reason"),
 };
 
-static char *pevt_ctcpsnd_help[] = {
+static char * const pevt_ctcpsnd_help[] = {
 	N_("The sound"),
 	N_("The nick of the person"),
 };
 
-static char *pevt_ctcpgen_help[] = {
+static char * const pevt_ctcpgen_help[] = {
 	N_("The CTCP event"),
 	N_("The nick of the person"),
 };
 
-static char *pevt_ctcpgenc_help[] = {
+static char * const pevt_ctcpgenc_help[] = {
 	N_("The CTCP event"),
 	N_("The nick of the person"),
 	N_("The Channel it's going to"),
 };
 
-static char *pevt_chansetkey_help[] = {
+static char * const pevt_chansetkey_help[] = {
 	N_("The nick of the person who set the key"),
 	N_("The key"),
 };
 
-static char *pevt_chansetlimit_help[] = {
+static char * const pevt_chansetlimit_help[] = {
 	N_("The nick of the person who set the limit"),
 	N_("The limit"),
 };
 
-static char *pevt_chanop_help[] = {
+static char * const pevt_chanop_help[] = {
 	N_("The nick of the person who did the op'ing"),
 	N_("The nick of the person who has been op'ed"),
 };
 
-static char *pevt_chanhop_help[] = {
+static char * const pevt_chanhop_help[] = {
 	N_("The nick of the person who has been halfop'ed"),
 	N_("The nick of the person who did the halfop'ing"),
 };
 
-static char *pevt_chanvoice_help[] = {
+static char * const pevt_chanvoice_help[] = {
 	N_("The nick of the person who did the voice'ing"),
 	N_("The nick of the person who has been voice'ed"),
 };
 
-static char *pevt_chanban_help[] = {
+static char * const pevt_chanban_help[] = {
 	N_("The nick of the person who did the banning"),
 	N_("The ban mask"),
 };
 
-static char *pevt_chanrmkey_help[] = {
+static char * const pevt_chanrmkey_help[] = {
 	N_("The nick who removed the key"),
 };
 
-static char *pevt_chanrmlimit_help[] = {
+static char * const pevt_chanrmlimit_help[] = {
 	N_("The nick who removed the limit"),
 };
 
-static char *pevt_chandeop_help[] = {
+static char * const pevt_chandeop_help[] = {
 	N_("The nick of the person of did the deop'ing"),
 	N_("The nick of the person who has been deop'ed"),
 };
-static char *pevt_chandehop_help[] = {
+static char * const pevt_chandehop_help[] = {
 	N_("The nick of the person of did the dehalfop'ing"),
 	N_("The nick of the person who has been dehalfop'ed"),
 };
 
-static char *pevt_chandevoice_help[] = {
+static char * const pevt_chandevoice_help[] = {
 	N_("The nick of the person of did the devoice'ing"),
 	N_("The nick of the person who has been devoice'ed"),
 };
 
-static char *pevt_chanunban_help[] = {
+static char * const pevt_chanunban_help[] = {
 	N_("The nick of the person of did the unban'ing"),
 	N_("The ban mask"),
 };
 
-static char *pevt_chanexempt_help[] = {
+static char * const pevt_chanexempt_help[] = {
 	N_("The nick of the person who did the exempt"),
 	N_("The exempt mask"),
 };
 
-static char *pevt_chanrmexempt_help[] = {
+static char * const pevt_chanrmexempt_help[] = {
 	N_("The nick of the person removed the exempt"),
 	N_("The exempt mask"),
 };
 
-static char *pevt_chaninvite_help[] = {
+static char * const pevt_chaninvite_help[] = {
 	N_("The nick of the person who did the invite"),
 	N_("The invite mask"),
 };
 
-static char *pevt_chanrminvite_help[] = {
+static char * const pevt_chanrminvite_help[] = {
 	N_("The nick of the person removed the invite"),
 	N_("The invite mask"),
 };
 
-static char *pevt_chanmodegen_help[] = {
+static char * const pevt_chanmodegen_help[] = {
 	N_("The nick of the person setting the mode"),
 	N_("The mode's sign (+/-)"),
 	N_("The mode letter"),
 	N_("The channel it's being set on"),
 };
 
-static char *pevt_whois1_help[] = {
+static char * const pevt_whois1_help[] = {
 	N_("Nickname"),
 	N_("Username"),
 	N_("Host"),
 	N_("Full name"),
 };
 
-static char *pevt_whois2_help[] = {
+static char * const pevt_whois2_help[] = {
 	N_("Nickname"),
 	N_("Channel Membership/\"is an IRC operator\""),
 };
 
-static char *pevt_whois3_help[] = {
+static char * const pevt_whois3_help[] = {
 	N_("Nickname"),
 	N_("Server Information"),
 };
 
-static char *pevt_whois4_help[] = {
+static char * const pevt_whois4_help[] = {
 	N_("Nickname"),
 	N_("Idle time"),
 };
 
-static char *pevt_whois4t_help[] = {
+static char * const pevt_whois4t_help[] = {
 	N_("Nickname"),
 	N_("Idle time"),
 	N_("Signon time"),
 };
 
-static char *pevt_whois5_help[] = {
+static char * const pevt_whois5_help[] = {
 	N_("Nickname"),
 	N_("Away reason"),
 };
 
-static char *pevt_whois6_help[] = {
+static char * const pevt_whois6_help[] = {
 	N_("Nickname"),
 };
 
-static char *pevt_whoisid_help[] = {
+static char * const pevt_whoisid_help[] = {
 	N_("Nickname"),
 	N_("Message"),
 };
 
-static char *pevt_whoisauth_help[] = {
+static char * const pevt_whoisauth_help[] = {
 	N_("Nickname"),
 	N_("Message"),
 	N_("Account"),
 };
 
-static char *pevt_whoisrealhost_help[] = {
+static char * const pevt_whoisrealhost_help[] = {
 	N_("Nickname"),
 	N_("Real user@host"),
 	N_("Real IP"),
 	N_("Message"),
 };
 
-static char *pevt_generic_channel_help[] = {
+static char * const pevt_generic_channel_help[] = {
 	N_("Channel Name"),
 };
 
-static char *pevt_servertext_help[] = {
+static char * const pevt_servertext_help[] = {
 	N_("Text"),
 	N_("Server Name")
 };
 
-static char *pevt_invited_help[] = {
+static char * const pevt_invited_help[] = {
 	N_("Channel Name"),
 	N_("Nick of person who invited you"),
 	N_("Server Name"),
 };
 
-static char *pevt_usersonchan_help[] = {
+static char * const pevt_usersonchan_help[] = {
 	N_("Channel Name"),
 	N_("Users"),
 };
 
-static char *pevt_nickclash_help[] = {
+static char * const pevt_nickclash_help[] = {
 	N_("Nickname in use"),
 	N_("Nick being tried"),
 };
 
-static char *pevt_connfail_help[] = {
+static char * const pevt_connfail_help[] = {
 	N_("Error"),
 };
 
-static char *pevt_connect_help[] = {
+static char * const pevt_connect_help[] = {
 	N_("Host"),
 	N_("IP"),
 	N_("Port"),
 };
 
-static char *pevt_sconnect_help[] = {
+static char * const pevt_sconnect_help[] = {
 	N_("PID"),
 };
 
-static char *pevt_generic_nick_help[] = {
+static char * const pevt_generic_nick_help[] = {
 	N_("Nickname"),
 };
 
-static char *pevt_chanmodes_help[] = {
+static char * const pevt_chanmodes_help[] = {
 	N_("Channel name"),
 	N_("Modes string"),
 };
 
-static char *pevt_rawmodes_help[] = {
+static char * const pevt_rawmodes_help[] = {
 	N_("Nickname"),
 	N_("Modes string"),
 };
 
-static char *pevt_kill_help[] = {
+static char * const pevt_kill_help[] = {
 	N_("Nickname"),
 	N_("Reason"),
 };
 
-static char *pevt_dccchaterr_help[] = {
+static char * const pevt_dccchaterr_help[] = {
 	N_("Nickname"),
 	N_("IP address"),
 	N_("Port"),
 	N_("Error"),
 };
 
-static char *pevt_dccstall_help[] = {
+static char * const pevt_dccstall_help[] = {
 	N_("DCC Type"),
 	N_("Filename"),
 	N_("Nickname"),
 };
 
-static char *pevt_generic_file_help[] = {
+static char * const pevt_generic_file_help[] = {
 	N_("Filename"),
 	N_("Error"),
 };
 
-static char *pevt_dccrecverr_help[] = {
+static char * const pevt_dccrecverr_help[] = {
 	N_("Filename"),
 	N_("Destination filename"),
 	N_("Nickname"),
 	N_("Error"),
 };
 
-static char *pevt_dccrecvcomp_help[] = {
+static char * const pevt_dccrecvcomp_help[] = {
 	N_("Filename"),
 	N_("Destination filename"),
 	N_("Nickname"),
 	N_("CPS"),
 };
 
-static char *pevt_dccconfail_help[] = {
+static char * const pevt_dccconfail_help[] = {
 	N_("DCC Type"),
 	N_("Nickname"),
 	N_("Error"),
 };
 
-static char *pevt_dccchatcon_help[] = {
+static char * const pevt_dccchatcon_help[] = {
 	N_("Nickname"),
 	N_("IP address"),
 };
 
-static char *pevt_dcccon_help[] = {
+static char * const pevt_dcccon_help[] = {
 	N_("Nickname"),
 	N_("IP address"),
 	N_("Filename"),
 };
 
-static char *pevt_dccsendfail_help[] = {
+static char * const pevt_dccsendfail_help[] = {
 	N_("Filename"),
 	N_("Nickname"),
 	N_("Error"),
 };
 
-static char *pevt_dccsendcomp_help[] = {
+static char * const pevt_dccsendcomp_help[] = {
 	N_("Filename"),
 	N_("Nickname"),
 	N_("CPS"),
 };
 
-static char *pevt_dccoffer_help[] = {
+static char * const pevt_dccoffer_help[] = {
 	N_("Filename"),
 	N_("Nickname"),
 	N_("Pathname"),
 };
 
-static char *pevt_dccfileabort_help[] = {
+static char * const pevt_dccfileabort_help[] = {
 	N_("Nickname"),
 	N_("Filename")
 };
 
-static char *pevt_dccchatabort_help[] = {
+static char * const pevt_dccchatabort_help[] = {
 	N_("Nickname"),
 };
 
-static char *pevt_dccresumeoffer_help[] = {
+static char * const pevt_dccresumeoffer_help[] = {
 	N_("Nickname"),
 	N_("Filename"),
 	N_("Position"),
 };
 
-static char *pevt_dccsendoffer_help[] = {
+static char * const pevt_dccsendoffer_help[] = {
 	N_("Nickname"),
 	N_("Filename"),
 	N_("Size"),
 	N_("IP address"),
 };
 
-static char *pevt_dccgenericoffer_help[] = {
+static char * const pevt_dccgenericoffer_help[] = {
 	N_("DCC String"),
 	N_("Nickname"),
 };
 
-static char *pevt_notifynumber_help[] = {
+static char * const pevt_notifynumber_help[] = {
 	N_("Number of notify items"),
 };
 
-static char *pevt_serverlookup_help[] = {
+static char * const pevt_serverlookup_help[] = {
 	N_("Servername"),
 };
 
-static char *pevt_servererror_help[] = {
+static char * const pevt_servererror_help[] = {
 	N_("Text"),
 };
 
-static char *pevt_foundip_help[] = {
+static char * const pevt_foundip_help[] = {
 	N_("IP"),
 };
 
-static char *pevt_dccrename_help[] = {
+static char * const pevt_dccrename_help[] = {
 	N_("Old Filename"),
 	N_("New Filename"),
 };
 
-static char *pevt_ctcpsend_help[] = {
+static char * const pevt_ctcpsend_help[] = {
 	N_("Receiver"),
 	N_("Message"),
 };
 
-static char *pevt_ignoreaddremove_help[] = {
+static char * const pevt_ignoreaddremove_help[] = {
 	N_("Hostmask"),
 };
 
-static char *pevt_resolvinguser_help[] = {
+static char * const pevt_resolvinguser_help[] = {
 	N_("Nickname"),
 	N_("Hostname"),
 };
 
-static char *pevt_malformed_help[] = {
+static char * const pevt_malformed_help[] = {
 	N_("Nickname"),
 	N_("The Packet"),
 };
 
-static char *pevt_pingtimeout_help[] = {
+static char * const pevt_pingtimeout_help[] = {
 	N_("Seconds"),
 };
 
-static char *pevt_uinvite_help[] = {
+static char * const pevt_uinvite_help[] = {
 	N_("Nick of person who have been invited"),
 	N_("Channel Name"),
 	N_("Server Name"),
 };
 
-static char *pevt_banlist_help[] = {
+static char * const pevt_banlist_help[] = {
 	N_("Channel"),
 	N_("Banmask"),
 	N_("Who set the ban"),
 	N_("Ban time"),
 };
 
-static char *pevt_discon_help[] = {
+static char * const pevt_discon_help[] = {
 	N_("Error"),
 };
 
@@ -1627,7 +1628,8 @@ sound_beep (session *sess)
 static char *
 sound_find_command (void)
 {
-	static const char *progs[] = {"esdplay", "soxplay", NULL};
+	/* some sensible unix players. You're bound to have one of them */
+	static const char * const progs[] = {"aplay", "esdplay", "soxplay", "artsplay", NULL};
 	char *cmd;
 	int i = 0;
 
@@ -1693,7 +1695,10 @@ sound_play (const char *file)
 		{
 			if (cmd)
 			{
-				snprintf (buf, sizeof (buf), "%s %s", cmd, file_fs);
+				if (strchr (file_fs, ' '))
+					snprintf (buf, sizeof (buf), "%s \"%s\"", cmd, file_fs);
+				else
+					snprintf (buf, sizeof (buf), "%s %s", cmd, file_fs);
 				buf[sizeof (buf) - 1] = '\0';
 				xchat_exec (buf);
 			}
@@ -1746,7 +1751,7 @@ sound_load ()
 		return;
 
 	evt[0] = 0;
-	while (waitline (fd, buf, sizeof buf) != -1)
+	while (waitline (fd, buf, sizeof buf, FALSE) != -1)
 	{
 		if (strncmp (buf, "event=", 6) == 0)
 		{
